@@ -24,8 +24,7 @@ class ApiClient:
         self.logger.debug(f"_apicall {method.upper()} {uri}, data:{data}")
         data.update(self.api_data)
         r = self.client.request(
-            # TODO: use some kind of urljoin here to avoid problems with slashes
-            method=method, url=f"{self.api_url}/{uri}", data=data
+            method=method, url=f"{self.api_url.strip('/')}/{uri}", data=data
         )
         if r.status_code != httpx.codes.OK:
             raise ApiClientException(
